#
# spec file for package libgarcon
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libgarcon-1-0
Name:           libgarcon
Version:        0.4.0
Release:        3.9
Summary:        Library Implementing the freedesktop.org Desktop Menu Specification
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://wiki.xfce.org/dev/garcon
Source:         http://archive.xfce.org/src/libs/garcon/0.4/garcon-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE libgarcon-x-suse-unimportant-support.patch gber@opensuse.org -- Hide desktop files marked with X-SuSE-Unimportant
Patch0:         libgarcon-x-suse-unimportant-support.patch
BuildRequires:  intltool
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxfce4ui-1)
BuildRequires:  pkgconfig(libxfce4util-1.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Garcon is a library based on GLib and GIO which implements the freedesktop.org
Desktop Menu Specification. It is the sucessor to libxfce4menu and covers
almost every part of the menu specification except for legacy menus and a few
XML attributes. It is capable of loading menus modified with menu editors such
as Alacarte and also supports merging.

%package -n %{libname}
Summary:        Library Implementing the freedesktop.org Desktop Menu Specification
Group:          System/Libraries
# uses exo-open
Requires:       exo-tools
# contains just menu data that needs to be dragged in at a low level
Recommends:     %{name}-data

%description -n %{libname}
Garcon is a library based on GLib and GIO which implements the freedesktop.org
Desktop Menu Specification. It is the sucessor to libxfce4menu and covers
almost every part of the menu specification except for legacy menus and a few
XML attributes. It is capable of loading menus modified with menu editors such
as Alacarte and also supports merging.

%package data
Summary:        Data Files for garcon
Group:          System/GUI/XFCE
Requires:       %{name}-branding = %{version}
Recommends:     %{name}-lang = %{version}
BuildArch:      noarch

%description data
This package provides data files for garcon.

%package devel
Summary:        Development Files for garcon
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(gtk+-2.0)
Requires:       pkgconfig(libxfce4ui-1)
Requires:       pkgconfig(libxfce4util-1.0)
Recommends:     %{name}-doc = %{version}

%description devel
This package contains the files needed for developing applications based on
garcon.

%package doc
Summary:        Documentation for garcon
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package includes the documentation for garcon.

%package branding-upstream
Summary:        Upstream Branding of garcon
Group:          System/GUI/XFCE
# the menu references xfce4-about.desktop
Requires:       libxfce4ui-tools
Supplements:    packageand(%{name}-data:branding-upstream)
# BRAND: xfce-applications.menu: Provides the Xfce applications menu.
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for garcon.

# this should be replaced by %%lang_package once bnc#513786 is resolved
%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{name}-data = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{name}-data)
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q -n garcon-%{version}
%patch0 -p1

%build
%configure \
  --disable-static \
  --enable-gtk-doc
make %{?_smp_mflags} V=1

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang garcon %{?no_lang_C}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libgarcon-*.so.*

%files data
%defattr(-,root,root)
%dir %{_datadir}/desktop-directories
%{_datadir}/desktop-directories/*.directory

%files lang -f garcon.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%{_includedir}/garcon-1/
%{_includedir}/garcon-gtk2-1/
%{_libdir}/pkgconfig/garcon-1.pc
%{_libdir}/pkgconfig/garcon-gtk2-1.pc
%{_libdir}/libgarcon-1.so
%{_libdir}/libgarcon-gtk2-1.so

%files doc
%defattr(-,root,root)
%doc AUTHORS COPYING HACKING NEWS README STATUS TODO
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/garcon/

%files branding-upstream
%defattr(-,root,root)
%dir %{_sysconfdir}/xdg/menus
%{_sysconfdir}/xdg/menus/xfce-applications.menu

%changelog
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.4.0
  - update intltool (bxo#8930)
  - fix menu icons for misconfigured desktop files (bxo#10709)
  - add case insensitive sorting to the menu (bxo#10594)
  - don't force URLs to be opened in a web browser (bxo#10212)
  - translation updates
* Wed Apr 30 2014 gber@opensuse.org
- update to version 0.3.0
  - avoid direct include of garcon-menu.h
  - add garcon_set_environment_xdg() function
  - add a garcon-gtk library for common gtk functions
  - bail out of creating a directory menu if it doesn't have a name
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 0.2.1
  - g_thread_init is deprecated since glib 2.32
  - remove unmaintained translations
  - fix deprecating warnings in tests
  - use new mutex locking api if available
  - autotools updates
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 0.2.0
  - updates for xfce4-run.desktop
  - remove xfhelp4.desktop from the menu
  - add debugging for file monitoring and reloading
  - reduce signal emission on delete events
  - translation updates
- make libgarcon-1-0 depend on exo-tools, it uses exo-open for
  Type=Link items
- make libgarcon-branding-upstream depend on libxfce4ui-tools since
  the included menu references xfce4-about.desktop
* Fri Apr 27 2012 gber@opensuse.org
- make the libgarcon-1-0 recommend -data which in turn requires
  - branding rather than recommending -branding
* Sat Apr 14 2012 gber@opensuse.org
- make -branding packages depend on -data and not the other way
  around
- make libgarcon-1-0 recommend -branding
* Sat Apr 14 2012 gber@opensuse.org
- update to version 0.1.12
  - add missing or fix incorrect licenses
  - fix segfault if null is set
  - translation updates
* Sat Mar 31 2012 gber@opensuse.org
- update to version 0.1.11
  - use applications-science icon for education directory
  - translation updates
* Mon Mar 26 2012 gber@opensuse.org
- correct build dependencies
- split off -lang and -data subpackages and move unversioned menu
  data to the latter
* Sun Feb 12 2012 gber@opensuse.org
- update to version 0.1.10
  - add hardware and personal directories
  - support Link desktop types
  - translation updates
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Mon Sep 19 2011 gber@opensuse.org
- update to version 0.1.9
  - rename Network category to Internet
  - queue multiple reload-required signals
  - speedup a number of critical code-paths
  - use GSList instead of GList where possible
  - Use XfceRc instead of GKeyFile, this makes garcon depend on
    libxfce4util, but is faster and more memory efficient.
  - return an error string instead of freeing it, causing a sefgault
    in xfce4-panel
  - do not decrement the internal refcount of items, this should
    fixed the usage of <OnlyUnallocated/>
  - translations updates
* Sun Jun 19 2011 gber@opensuse.org
- update to version 0.1.8
  - removed the science toplevel category
  - handle local desktop file loading directly
  - bugfixes
  - translation updates
* Sat Apr 16 2011 gber@opensuse.org
- update to version 0.1.7
  - respect XDG priorities when returning the menu file (bxo#7470)
  - translation updates
* Wed Apr  6 2011 gber@opensuse.org
- update to version 0.1.6
  - add <DefaultMergeDirs/> to xfce-applications.menu
  - also try the garcon install sysconfigdir for config lookups
  - use Xdt macros for debugging and linker optimizations
  - default menu prefix to "xfce-"
  - bugfixes
  - translation updates
* Sun Jan 30 2011 gber@opensuse.org
- supplement libgarcon-1-0 not libgarcon
* Mon Jan 17 2011 gber@opensuse.org
- updated to version 0.1.5
  - bugfixes
* Wed Jan  5 2011 gber@opensuse.org
- fixed typos
- added -branding-upstream subpackage
* Fri Dec 24 2010 gber@opensuse.org
- show compiler output
- remove unsupported locales
* Fri Dec 24 2010 gber@opensuse.org
- improved summries/descriptions
- corrected categories
* Tue Dec 21 2010 gber@opensuse.org
- add support for X-SuSE-Unimportant
* Sun Dec  5 2010 andrea@opensuse.org
- update to 0.1.4
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Tue Nov 30 2010 andrea@opensuse.org
- used some macros
- fixed rpm groups
* Mon Nov  8 2010 prusnak@opensuse.org
- updated to 0.1.3
- drop preamble.patch (included upstream)
* Mon Apr 26 2010 prusnak@suse.cz
- fix license in preamble (preamble.patch)
* Fri Mar 12 2010 prusnak@suse.cz
- updated to 0.1.1
* Fri Nov 13 2009 prusnak@suse.cz
- created package (version 0.1.0)
